@@ -65,6 +65,8 @@ class ListTransactionsV2Request:
         self.destinationAccountKey = None
         # Destination account type
         self.destinationAccountType = None
+        # The unique identifier key of a wallet account, used to query all transactions under that wallet. This is only supported for VAULT_ACCOUNT type wallets. This has a higher priority than sourceAccountKey, sourceAccountType, destinationAccountKey, destinationAccountType, and realDestinationAccountType. If accountKey is passed along with the five parameters mentioned above, only accountKey will be effective
+        self.accountKey = None
         # Start time for creating a transaction, UNIX timestamp (ms)
         self.createTimeMin = None
         # End time for creating a transaction, UNIX timestamp (ms)
